==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationExecutionEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapAuthenticationExecutionEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> entityFieldDelegate;
    public MapAuthenticationExecutionEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthenticator() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthenticator(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthenticatorConfig() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR_CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthenticatorConfig(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR_CONFIG, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.models.AuthenticationExecutionModel.Requirement getRequirement() {
        return (org.keycloak.models.AuthenticationExecutionModel.Requirement) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.REQUIREMENT);
    }
    @SuppressWarnings("unchecked") @Override public void setRequirement(org.keycloak.models.AuthenticationExecutionModel.Requirement p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.REQUIREMENT, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isAutheticatorFlow() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHETICATOR_FLOW);
    }
    @SuppressWarnings("unchecked") @Override public void setAutheticatorFlow(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHETICATOR_FLOW, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getFlowId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.FLOW_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setFlowId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.FLOW_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getParentFlowId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PARENT_FLOW_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setParentFlowId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PARENT_FLOW_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getPriority() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PRIORITY);
    }
    @SuppressWarnings("unchecked") @Override public void setPriority(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PRIORITY, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationExecutionEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthenticationExecutionEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> entityFieldDelegate;
    public MapAuthenticationExecutionEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthenticator() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthenticator(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthenticatorConfig() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR_CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthenticatorConfig(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHENTICATOR_CONFIG, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.models.AuthenticationExecutionModel.Requirement getRequirement() {
        return (org.keycloak.models.AuthenticationExecutionModel.Requirement) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.REQUIREMENT);
    }
    @SuppressWarnings("unchecked") @Override public void setRequirement(org.keycloak.models.AuthenticationExecutionModel.Requirement p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.REQUIREMENT, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isAutheticatorFlow() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHETICATOR_FLOW);
    }
    @SuppressWarnings("unchecked") @Override public void setAutheticatorFlow(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.AUTHETICATOR_FLOW, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getFlowId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.FLOW_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setFlowId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.FLOW_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getParentFlowId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PARENT_FLOW_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setParentFlowId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PARENT_FLOW_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getPriority() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PRIORITY);
    }
    @SuppressWarnings("unchecked") @Override public void setPriority(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationExecutionEntityFields.PRIORITY, p0);
    }
}
